==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm5/lib/igc-geographic-high-density-scatter-series-component.js <==
import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcProgressiveLoadStatusEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicMapSeriesHostComponent } from "./igc-geographic-map-series-host-component";
import { GeographicHighDensityScatterSeries } from "./GeographicHighDensityScatterSeries";
import { getAllPropertyNames, toSpinal, ensureBool, colorToString, stringToColor } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a HighDensityScatterSeries.
*/
var IgcGeographicHighDensityScatterSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicHighDensityScatterSeriesComponent, _super);
    function IgcGeographicHighDensityScatterSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._progressiveLoadStatusChanged = null;
        _this._progressiveLoadStatusChanged_wrapped = null;
        return _this;
    }
    IgcGeographicHighDensityScatterSeriesComponent.prototype.createImplementation = function () {
        return new GeographicHighDensityScatterSeries();
    };
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicHighDensityScatterSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicHighDensityScatterSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicHighDensityScatterSeriesComponent._observedAttributesIgcGeographicHighDensityScatterSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicHighDensityScatterSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicHighDensityScatterSeriesComponent._observedAttributesIgcGeographicHighDensityScatterSeriesComponent = names;
            }
            return IgcGeographicHighDensityScatterSeriesComponent._observedAttributesIgcGeographicHighDensityScatterSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicHighDensityScatterSeriesComponent.register = function () {
        if (!IgcGeographicHighDensityScatterSeriesComponent._isElementRegistered) {
            IgcGeographicHighDensityScatterSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcGeographicHighDensityScatterSeriesComponent.htmlTagName, IgcGeographicHighDensityScatterSeriesComponent);
        }
    };
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "isPixel", {
        /**
         * Gets whether the current series shows pixels.
        */
        get: function () {
            return this.i.e2;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "latitudeMemberPath", {
        /**
         * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
        */
        get: function () {
            return this.i.us;
        },
        set: function (v) {
            this.i.us = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "longitudeMemberPath", {
        /**
         * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
        */
        get: function () {
            return this.i.uu;
        },
        set: function (v) {
            this.i.uu = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "useBruteForce", {
        /**
         * Gets or sets the whether to use use brute force mode.
        */
        get: function () {
            return this.i.uh;
        },
        set: function (v) {
            this.i.uh = ensureBool(v);
            this._a("useBruteForce", this.i.uh);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "progressiveLoad", {
        /**
         * Gets or sets the whether to progressively load the data into the chart.
        */
        get: function () {
            return this.i.ug;
        },
        set: function (v) {
            this.i.ug = ensureBool(v);
            this._a("progressiveLoad", this.i.ug);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "mouseOverEnabled", {
        /**
         * Gets or sets the whether the chart reacts to mouse move events.
        */
        get: function () {
            return this.i.uf;
        },
        set: function (v) {
            this.i.uf = ensureBool(v);
            this._a("mouseOverEnabled", this.i.uf);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "heatMinimum", {
        /**
         * Gets or sets the density value that maps to the minimum heat color.
        */
        get: function () {
            return this.i.uj;
        },
        set: function (v) {
            this.i.uj = +v;
            this._a("heatMinimum", this.i.uj);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "heatMaximum", {
        /**
         * Gets or sets the value that maps to the maximum heat color.
        */
        get: function () {
            return this.i.ui;
        },
        set: function (v) {
            this.i.ui = +v;
            this._a("heatMaximum", this.i.ui);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "heatMinimumColor", {
        /**
         * Gets or sets the color to use for the minimum end of the scale.
        */
        get: function () {
            return colorToString(this.i.vd);
        },
        set: function (v) {
            this.i.vd = stringToColor(v);
            this._a("heatMinimumColor", colorToString(this.i.vd));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "heatMaximumColor", {
        /**
         * Gets or sets the color to use for the maximum end of the scale.
        */
        get: function () {
            return colorToString(this.i.vc);
        },
        set: function (v) {
            this.i.vc = stringToColor(v);
            this._a("heatMaximumColor", colorToString(this.i.vc));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "pointExtent", {
        /**
         * Gets or sets the the pixel extent of the square data points that are rendered.
        */
        get: function () {
            return this.i.um;
        },
        set: function (v) {
            this.i.um = +v;
            this._a("pointExtent", this.i.um);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "progressiveStatus", {
        /**
         * Represents the current status of the progressive load of the series. It will range from 0 to 100, where 100 is fully loaded.
        */
        get: function () {
            return this.i.un;
        },
        set: function (v) {
            this.i.un = +v;
            this._a("progressiveStatus", this.i.un);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "progressiveLoadStatusChanged", {
        /**
         * Raised when the progressive loading state of the series has changed.
        */
        get: function () {
            return this._progressiveLoadStatusChanged;
        },
        set: function (ev) {
            var _this = this;
            if (this._progressiveLoadStatusChanged_wrapped !== null) {
                this.i.progressiveLoadStatusChanged = delegateRemove(this.i.progressiveLoadStatusChanged, this._progressiveLoadStatusChanged_wrapped);
                this._progressiveLoadStatusChanged_wrapped = null;
                this._progressiveLoadStatusChanged = null;
            }
            this._progressiveLoadStatusChanged = ev;
            this._progressiveLoadStatusChanged_wrapped = function (o, e) {
                var outerArgs = new IgcProgressiveLoadStatusEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeProgressiveLoadStatusChanged) {
                    _this.beforeProgressiveLoadStatusChanged(_this, outerArgs);
                }
                if (_this._progressiveLoadStatusChanged) {
                    _this._progressiveLoadStatusChanged(_this, outerArgs);
                }
            };
            this.i.progressiveLoadStatusChanged = delegateCombine(this.i.progressiveLoadStatusChanged, this._progressiveLoadStatusChanged_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicHighDensityScatterSeriesComponent._observedAttributesIgcGeographicHighDensityScatterSeriesComponent = null;
    IgcGeographicHighDensityScatterSeriesComponent.htmlTagName = "igc-geographic-high-density-scatter-series";
    IgcGeographicHighDensityScatterSeriesComponent._isElementRegistered = false;
    return IgcGeographicHighDensityScatterSeriesComponent;
}(IgcGeographicMapSeriesHostComponent));
export { IgcGeographicHighDensityScatterSeriesComponent };

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm5/lib/igc-geographic-high-density-scatter-series-component.js <==
import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcProgressiveLoadStatusEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicMapSeriesHostComponent } from "./igc-geographic-map-series-host-component";
import { GeographicHighDensityScatterSeries } from "./GeographicHighDensityScatterSeries";
import { getAllPropertyNames, toSpinal, ensureBool, colorToString, stringToColor } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a HighDensityScatterSeries.
*/
var IgcGeographicHighDensityScatterSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicHighDensityScatterSeriesComponent, _super);
    function IgcGeographicHighDensityScatterSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._progressiveLoadStatusChanged = null;
        _this._progressiveLoadStatusChanged_wrapped = null;
        return _this;
    }
    IgcGeographicHighDensityScatterSeriesComponent.prototype.createImplementation = function () {
        return new GeographicHighDensityScatterSeries();
    };
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicHighDensityScatterSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicHighDensityScatterSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicHighDensityScatterSeriesComponent._observedAttributesIgcGeographicHighDensityScatterSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicHighDensityScatterSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicHighDensityScatterSeriesComponent._observedAttributesIgcGeographicHighDensityScatterSeriesComponent = names;
            }
            return IgcGeographicHighDensityScatterSeriesComponent._observedAttributesIgcGeographicHighDensityScatterSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicHighDensityScatterSeriesComponent.register = function () {
        if (!IgcGeographicHighDensityScatterSeriesComponent._isElementRegistered) {
            IgcGeographicHighDensityScatterSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcGeographicHighDensityScatterSeriesComponent.htmlTagName, IgcGeographicHighDensityScatterSeriesComponent);
        }
    };
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "isPixel", {
        /**
         * Gets whether the current series shows pixels.
        */
        get: function () {
            return this.i.fo;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "latitudeMemberPath", {
        /**
         * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
        */
        get: function () {
            return this.i.xp;
        },
        set: function (v) {
            this.i.xp = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "longitudeMemberPath", {
        /**
         * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
        */
        get: function () {
            return this.i.xr;
        },
        set: function (v) {
            this.i.xr = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "useBruteForce", {
        /**
         * Gets or sets the whether to use use brute force mode.
        */
        get: function () {
            return this.i.xe;
        },
        set: function (v) {
            this.i.xe = ensureBool(v);
            this._a("useBruteForce", this.i.xe);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "progressiveLoad", {
        /**
         * Gets or sets the whether to progressively load the data into the chart.
        */
        get: function () {
            return this.i.xd;
        },
        set: function (v) {
            this.i.xd = ensureBool(v);
            this._a("progressiveLoad", this.i.xd);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "mouseOverEnabled", {
        /**
         * Gets or sets the whether the chart reacts to mouse move events.
        */
        get: function () {
            return this.i.xc;
        },
        set: function (v) {
            this.i.xc = ensureBool(v);
            this._a("mouseOverEnabled", this.i.xc);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "heatMinimum", {
        /**
         * Gets or sets the density value that maps to the minimum heat color.
        */
        get: function () {
            return this.i.xg;
        },
        set: function (v) {
            this.i.xg = +v;
            this._a("heatMinimum", this.i.xg);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "heatMaximum", {
        /**
         * Gets or sets the value that maps to the maximum heat color.
        */
        get: function () {
            return this.i.xf;
        },
        set: function (v) {
            this.i.xf = +v;
            this._a("heatMaximum", this.i.xf);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "heatMinimumColor", {
        /**
         * Gets or sets the color to use for the minimum end of the scale.
        */
        get: function () {
            return colorToString(this.i.ya);
        },
        set: function (v) {
            this.i.ya = stringToColor(v);
            this._a("heatMinimumColor", colorToString(this.i.ya));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "heatMaximumColor", {
        /**
         * Gets or sets the color to use for the maximum end of the scale.
        */
        get: function () {
            return colorToString(this.i.x9);
        },
        set: function (v) {
            this.i.x9 = stringToColor(v);
            this._a("heatMaximumColor", colorToString(this.i.x9));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "pointExtent", {
        /**
         * Gets or sets the the pixel extent of the square data points that are rendered.
        */
        get: function () {
            return this.i.xj;
        },
        set: function (v) {
            this.i.xj = +v;
            this._a("pointExtent", this.i.xj);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "progressiveStatus", {
        /**
         * Represents the current status of the progressive load of the series. It will range from 0 to 100, where 100 is fully loaded.
        */
        get: function () {
            return this.i.xk;
        },
        set: function (v) {
            this.i.xk = +v;
            this._a("progressiveStatus", this.i.xk);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicHighDensityScatterSeriesComponent.prototype, "progressiveLoadStatusChanged", {
        /**
         * Raised when the progressive loading state of the series has changed.
        */
        get: function () {
            return this._progressiveLoadStatusChanged;
        },
        set: function (ev) {
            var _this = this;
            if (this._progressiveLoadStatusChanged_wrapped !== null) {
                this.i.progressiveLoadStatusChanged = delegateRemove(this.i.progressiveLoadStatusChanged, this._progressiveLoadStatusChanged_wrapped);
                this._progressiveLoadStatusChanged_wrapped = null;
                this._progressiveLoadStatusChanged = null;
            }
            this._progressiveLoadStatusChanged = ev;
            this._progressiveLoadStatusChanged_wrapped = function (o, e) {
                var outerArgs = new IgcProgressiveLoadStatusEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeProgressiveLoadStatusChanged) {
                    _this.beforeProgressiveLoadStatusChanged(_this, outerArgs);
                }
                if (_this._progressiveLoadStatusChanged) {
                    _this._progressiveLoadStatusChanged(_this, outerArgs);
                }
            };
            this.i.progressiveLoadStatusChanged = delegateCombine(this.i.progressiveLoadStatusChanged, this._progressiveLoadStatusChanged_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicHighDensityScatterSeriesComponent._observedAttributesIgcGeographicHighDensityScatterSeriesComponent = null;
    IgcGeographicHighDensityScatterSeriesComponent.htmlTagName = "igc-geographic-high-density-scatter-series";
    IgcGeographicHighDensityScatterSeriesComponent._isElementRegistered = false;
    return IgcGeographicHighDensityScatterSeriesComponent;
}(IgcGeographicMapSeriesHostComponent));
export { IgcGeographicHighDensityScatterSeriesComponent };
